@@ -471,8 +471,11 @@ github_handlers = {
         "pull_request" : handle_pull_request,
 #        "push" : handle_push,
         }
-
-github = GitHub(config.github_username, config.github_password)
+if not (bool(config.github_username and config.github_password) ^ bool(config.github_apikey)):
+    raise SystemExit("No valid github authentication provided, provide "
+                     "username/password or an API key in the configuration "
+                     "file.")
+github = GitHub(config.github_username, config.github_password, token=config.github_apikey)
 queue = Queue()
 ShellWorker(queue)
 
@@ -504,7 +507,3 @@ def main():
 
     PullRequest.cancel_all()
     log.info("murdock shut down.")
-
-if __name__ == "__main__":
-    main()
-
